@@ -30,8 +30,26 @@ const Application = new Lang.Class({
                       flags: Gio.ApplicationFlags.HANDLES_OPEN });
 
         GLib.set_application_name('Polari');
-        this._window = null;
         this._retryData = new Map();
+
+        this.add_main_option('start-client', 0,
+                             GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
+                             'Start Telephathy client', null);
+        this.connect('handle-local-options', (o, dict) => {
+            try {
+                this.register(null);
+            } catch(e) {
+                return 1;
+            }
+
+            let v = dict.lookup_value('start-client', null);
+            if (v && v.get_boolean()) {
+                this.activate_action('start-client', null);
+                return 0;
+            }
+
+            return -1;
+        });
     },
 
     isRoomFocused: function(room) {
@@ -82,6 +100,8 @@ const Application = new Lang.Class({
             parameter_type: GLib.VariantType.new('o') },
           { name: 'discard-identify-password',
             parameter_type: GLib.VariantType.new('o') },
+          { name: 'start-client',
+            activate: Lang.bind(this, this._onStartClient) },
           { name: 'help',
             activate: Lang.bind(this, this._onShowHelp),
             accels: ['F1'] },
@@ -144,26 +164,19 @@ const Application = new Lang.Class({
     },
 
     vfunc_activate: function() {
-        if (!this._telepathyClient) {
-            let params = {
-                name: 'Polari',
-                account_manager: this._accountsMonitor.accountManager,
-                uniquify_name: false
-            };
-            this._telepathyClient = new TelepathyClient.TelepathyClient(params);
-        }
+        this.activate_action('start-client', null);
 
-        if (!this._window) {
-            this._window = new MainWindow.MainWindow({ application: this });
-            this._window.connect('destroy',
-                                 () => { this.emit('prepare-shutdown'); });
-            this._window.connect('notify::active-room',
-                                 () => { this.emit('room-focus-changed'); });
-            this._window.connect('notify::is-active',
-                                 () => { this.emit('room-focus-changed'); });
-            this._window.show_all();
+        if (!this.active_window) {
+            let window = new MainWindow.MainWindow({ application: this });
+            window.connect('destroy',
+                           () => { this.emit('prepare-shutdown'); });
+            window.connect('notify::active-room',
+                           () => { this.emit('room-focus-changed'); });
+            window.connect('notify::is-active',
+                           () => { this.emit('room-focus-changed'); });
+            window.show_all();
         }
-        this._window.present();
+        this.active_window.present();
     },
 
     vfunc_window_added: function(window) {
@@ -294,13 +307,13 @@ const Application = new Lang.Class({
     },
 
     _onShowJoinDialog: function() {
-        this._window.showJoinRoomDialog();
+        this.active_window.showJoinRoomDialog();
     },
 
     _maybePresent: function(time) {
         let [present, ] = Tp.user_action_time_should_present(time);
 
-        if (!this._window || present)
+        if (!this.active_window || present)
             this.activate();
     },
 
@@ -417,7 +430,7 @@ const Application = new Lang.Class({
     },
 
     _onLeaveCurrentRoom: function() {
-        let room = this._window.active_room;
+        let room = this.active_window.active_room;
         if (!room)
             return;
         let action = this.lookup_action('leave-room');
@@ -463,7 +476,7 @@ const Application = new Lang.Class({
         let accountPath = parameter.deep_unpack();
         let account = this._accountsMonitor.lookupAccount(accountPath);
         let dialog = new Connections.ConnectionProperties(account);
-        dialog.transient_for = this._window;
+        dialog.transient_for = this.active_window;
         dialog.connect('response', Lang.bind(this,
             function(w, response) {
                 w.destroy();
@@ -471,6 +484,18 @@ const Application = new Lang.Class({
         dialog.show();
     },
 
+    _onStartClient: function() {
+        if (this._telepathyClient)
+            return;
+
+        let params = {
+            name: 'Polari',
+            account_manager: this._accountsMonitor.accountManager,
+            uniquify_name: false
+        };
+        this._telepathyClient = new TelepathyClient.TelepathyClient(params);
+    },
+
     _onShowHelp: function() {
         Utils.openURL('help:org.gnome.Polari', Gtk.get_current_event_time());
     },
@@ -509,7 +534,7 @@ const Application = new Lang.Class({
             website_label: _("Learn more about Polari"),
             website: 'https://wiki.gnome.org/Apps/Polari',
 
-            transient_for: this._window,
+            transient_for: this.active_window,
             modal: true
         };
 
@@ -522,6 +547,6 @@ const Application = new Lang.Class({
     },
 
     _onQuit: function() {
-        this._window.destroy();
+        this.get_windows().reverse().forEach(w => { w.destroy(); });
     }
 });
