@@ -3,15 +3,16 @@ const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
+const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 
 const AccountsMonitor = imports.accountsMonitor;
 const AppNotifications = imports.appNotifications;
-const ChatroomManager = imports.chatroomManager;
 const JoinDialog = imports.joinDialog;
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const RoomList = imports.roomList;
+const RoomManager = imports.roomManager;
 const RoomStack = imports.roomStack;
 const UserList = imports.userList;
 const Utils = imports.utils;
@@ -109,27 +110,33 @@ const MainWindow = new Lang.Class({
                                                       'subtitle-visible',
                                                       'subtitle-visible',
                                                       GObject.ParamFlags.READABLE,
-                                                      false)
+                                                      false),
+        'active-room': GObject.ParamSpec.object('active-room',
+                                                'active-room',
+                                                'active-room',
+                                                GObject.ParamFlags.READWRITE,
+                                                Polari.Room.$gtype)
     },
+    Signals: { 'active-room-state-changed': {} },
 
     _init: function(params) {
         this._subtitle = '';
         params.show_menubar = false;
 
-        this.parent(params);
-
-        this._addApplicationStyle();
-
-        this._rooms = {};
-        this._entries = {};
-
         this._room = null;
-        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
-        this._gtkSettings = Gtk.Settings.get_default();
+        this._lastActiveRoom = null;
 
         this._displayNameChangedId = 0;
         this._topicChangedId = 0;
         this._membersChangedId = 0;
+        this._channelChangedId = 0;
+
+        this.parent(params);
+
+        this._addApplicationStyle();
+
+        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
+        this._gtkSettings = Gtk.Settings.get_default();
 
         this._currentSize = [-1, -1];
         this._isMaximized = false;
@@ -157,19 +164,16 @@ const MainWindow = new Lang.Class({
             }));
 
         this._accountsMonitor = AccountsMonitor.getDefault();
-        this._accountsMonitor.connect('accounts-changed', Lang.bind(this,
-            function(am) {
-                let accounts = am.dupAccounts();
-                this._roomListRevealer.reveal_child = accounts.some(function(a) {
-                    return a.enabled;
-                });
-            }));
+        this._accountsMonitor.connect('accounts-changed',
+                                      Lang.bind(this, this._onAccountsChanged));
+        this._onAccountsChanged(this._accountsMonitor);
 
-        this._roomManager = ChatroomManager.getDefault();
-        this._roomManager.connect('active-changed',
-                                  Lang.bind(this, this._activeRoomChanged));
-        this._roomManager.connect('active-state-changed',
-                                  Lang.bind(this, this._updateUserListLabel));
+        this._roomManager = RoomManager.getDefault();
+        this._roomManager.connect('rooms-loaded',
+                                  Lang.bind(this, this._onRoomsLoaded));
+        this._roomManager.connect('room-removed',
+                                  Lang.bind(this, this._onRoomRemoved));
+        this._onRoomsLoaded();
 
         this._updateUserListLabel();
 
@@ -189,12 +193,12 @@ const MainWindow = new Lang.Class({
                                   Lang.bind(this, this._updateDecorations));
         this._updateDecorations();
 
-        this.connect('window-state-event',
-                            Lang.bind(this, this._onWindowStateEvent));
-        this.connect('size-allocate',
-                            Lang.bind(this, this._onSizeAllocate));
-        this.connect('delete-event',
-                            Lang.bind(this, this._onDelete));
+        this.connect('window-state-event', Lang.bind(this, this._onWindowStateEvent));
+        this.connect('size-allocate', Lang.bind(this, this._onSizeAllocate));
+        this.connect('destroy', Lang.bind(this, this._onDestroy));
+        this.connect('notify::active-room', () => {
+            this._updateUserListLabel();
+        });
 
         let size = this._settings.get_value('window-size').deep_unpack();
         if (size.length == 2)
@@ -202,8 +206,6 @@ const MainWindow = new Lang.Class({
 
         if (this._settings.get_boolean('window-maximized'))
             this.maximize();
-
-        this.show_all();
     },
 
     get subtitle() {
@@ -226,10 +228,27 @@ const MainWindow = new Lang.Class({
             this._currentSize = this.get_size(this);
     },
 
-    _onDelete: function(widget, event) {
+    _onDestroy: function(widget) {
         this._settings.set_boolean ('window-maximized', this._isMaximized);
         this._settings.set_value('window-size',
                                  GLib.Variant.new('ai', this._currentSize));
+
+        let serializedChannel = null;
+        if (this._lastActiveRoom)
+            serializedChannel = new GLib.Variant('a{sv}', {
+                account: new GLib.Variant('s', this._lastActiveRoom.account.object_path),
+                channel: new GLib.Variant('s', this._lastActiveRoom.channel_name)
+            });
+
+        if (serializedChannel)
+            this._settings.set_value('last-selected-channel', serializedChannel);
+        else
+            this._settings.reset('last-selected-channel');
+    },
+
+    _onAccountsChanged: function(am) {
+        let hasAccounts = this._accountsMonitor.enabledAccounts.length > 0;
+        this._roomListRevealer.reveal_child = hasAccounts;
     },
 
     _updateDecorations: function() {
@@ -248,20 +267,34 @@ const MainWindow = new Lang.Class({
         this._titlebarRight.set_decoration_layout(layoutRight);
     },
 
-    _activeRoomChanged: function(manager, room) {
+    get active_room() {
+        return this._room;
+    },
+
+    set active_room(room) {
+        if (room == this._room)
+            return;
+
         if (this._room) {
             this._room.disconnect(this._displayNameChangedId);
             this._room.disconnect(this._topicChangedId);
             this._room.disconnect(this._membersChangedId);
+            this._room.disconnect(this._channelChangedId);
         }
         this._displayNameChangedId = 0;
         this._topicChangedId = 0;
         this._membersChangedId = 0;
+        this._channelChangedId = 0;
 
+        if (room && room.type == Tp.HandleType.ROOM)
+            this._lastActiveRoom = room;
         this._room = room;
 
         this._updateTitlebar();
 
+        this.notify('active-room');
+        this.emit('active-room-state-changed');
+
         if (!this._room)
             return; // finished
 
@@ -274,6 +307,11 @@ const MainWindow = new Lang.Class({
         this._membersChangedId =
             this._room.connect('members-changed',
                                Lang.bind(this, this._updateUserListLabel));
+        this._channelChangedId =
+            this._room.connect('notify::channel', () => {
+                this._updateUserListLabel();
+                this.emit('active-room-state-changed');
+            });
     },
 
     _addApplicationStyle: function() {
@@ -292,6 +330,29 @@ const MainWindow = new Lang.Class({
         );
     },
 
+    _onRoomsLoaded: function(mgr) {
+        if (this.active_room)
+            return;
+
+        let selectedRoom = this._settings.get_value('last-selected-channel').deep_unpack();
+        for (let prop in selectedRoom)
+            selectedRoom[prop] = selectedRoom[prop].deep_unpack();
+
+        let roomId = null;
+        let account = this._accountsMonitor.lookupAccount(selectedRoom.account);
+        let channelName = selectedRoom.channel;
+        if (account && account.enabled && channelName)
+            roomId = Polari.create_room_id(account, channelName, Tp.HandleType.ROOM);
+
+        this.active_room = this._roomManager.lookupRoom(roomId) ||
+                           this._roomManager.rooms.shift();
+    },
+
+    _onRoomRemoved: function(mgr, room) {
+        if (room == this._lastActiveRoom)
+            this._lastActiveRoom = null;
+    },
+
     showJoinRoomDialog: function() {
         let dialog = new JoinDialog.JoinDialog({ transient_for: this });
         dialog.show();
